API Reference
=============

This section contains the Python API reference for Uncertainty Toolbox.

.. toctree::
  :maxdepth: 1

  data
  metrics
  metrics_calibration
  metrics_accuracy
  metrics_scoring_rule
  recalibration
  utils
  viz
